@@ -31,7 +31,6 @@ HOME = os.path.expanduser("~")
 EDM_ENVS_ROOT = os.path.join(HOME, ".edm", "envs")
 EDM_BIN = os.path.join(EDM_ENVS_ROOT, "edm", "bin")
 
-
 if IS_WINDOWS:
     GIT = "C:\\Git\\bin\\git"
 else:
@@ -61,9 +60,16 @@ def _login(env, app_id):
     util.write(environment_file, yaml.dump(t))
 
 
-def _edm(environment, verbose):
+def _edm(environment, app, verbose):
     click.secho("edm install", bold=True, fg="green")
     req = requirements.EDM_REQUIREMENTS
+    pip_req = ["uncertainties", "qimage2ndarray", "pymysql"]
+
+    if app == "pyvalve":
+        req.extend(["pyserial", "twisted"])
+    else:
+        pip_req.extend(["peakutils", "utm"])
+
     cmdargs = ["edm", "install", "-y"] + req
     active_python = os.path.join(HOME, ".edm")
     if environment:
@@ -77,6 +83,7 @@ def _edm(environment, verbose):
     if verbose:
         click.echo(f'requirements: {" ".join(req)}')
         click.echo(f'command: {" ".join(cmdargs)}')
+
     subprocess.call(cmdargs)
     subprocess.call(
         [
@@ -85,12 +92,8 @@ def _edm(environment, verbose):
             "pip",
             "install",
             "--no-dependencies",
-            "uncertainties",
-            "qimage2ndarray",
-            "peakutils",
-            "utm",
-            "pymysql",
         ]
+        + pip_req
     )
 
 
